Phoenix.SocketClient.Message.V1 (phoenix_socket_client v0.7.0)

DEPRECATED: V1 protocol serializer for legacy Phoenix Channels support.

This module provides compatibility with Phoenix Channels protocol v1.0.0. It is deprecated and will be removed in a future version. Use V2 protocol instead.